==> aliyun-java-sdk-cdn-3.0.10-sources.jar: com/aliyuncs/cdn/model/v20141111/SetL2OssKeyConfigRequest.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.cdn.model.v20141111;

import com.aliyuncs.RpcAcsRequest;
import com.aliyuncs.cdn.Endpoint;

/**
 * @author auto create
 * @version 
 */
public class SetL2OssKeyConfigRequest extends RpcAcsRequest<SetL2OssKeyConfigResponse> {
	
	public SetL2OssKeyConfigRequest() {
		super("Cdn", "2014-11-11", "SetL2OssKeyConfig", "cdn");
		try {
			com.aliyuncs.AcsRequest.class.getDeclaredField("productEndpointMap").set(this, Endpoint.endpointMap);
			com.aliyuncs.AcsRequest.class.getDeclaredField("productEndpointRegional").set(this, Endpoint.endpointRegionalType);
		} catch (Exception e) {}
	}

	private String securityToken;

	private String domainName;

	private Long ownerId;

	private String privateOssAuth;

	public String getBizSecurityToken() {
		return this.securityToken;
	}

	public void setBizSecurityToken(String securityToken) {
		this.securityToken = securityToken;
		if(securityToken != null){
			putQueryParameter("SecurityToken", securityToken);
		}
	}

	/**
	 * @deprecated use getBizSecurityToken instead of this.
	 */
	@Deprecated
	public String getSecurityToken() {
		return this.securityToken;
	}

	/**
	 * @deprecated use setBizSecurityToken instead of this.
	 */
	@Deprecated
	public void setSecurityToken(String securityToken) {
		this.securityToken = securityToken;
		if(securityToken != null){
			putQueryParameter("SecurityToken", securityToken);
		}
	}

	public String getDomainName() {
		return this.domainName;
	}

	public void setDomainName(String domainName) {
		this.domainName = domainName;
		if(domainName != null){
			putQueryParameter("DomainName", domainName);
		}
	}

	public Long getOwnerId() {
		return this.ownerId;
	}

	public void setOwnerId(Long ownerId) {
		this.ownerId = ownerId;
		if(ownerId != null){
			putQueryParameter("OwnerId", ownerId.toString());
		}
	}

	public String getPrivateOssAuth() {
		return this.privateOssAuth;
	}

	public void setPrivateOssAuth(String privateOssAuth) {
		this.privateOssAuth = privateOssAuth;
		if(privateOssAuth != null){
			putQueryParameter("PrivateOssAuth", privateOssAuth);
		}
	}

	@Override
	public Class<SetL2OssKeyConfigResponse> getResponseClass() {
		return SetL2OssKeyConfigResponse.class;
	}

}

==> aliyun-java-sdk-cdn-3.3.0-sources.jar: com/aliyuncs/cdn/model/v20141111/SetL2OssKeyConfigRequest.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.cdn.model.v20141111;

import com.aliyuncs.RpcAcsRequest;
import com.aliyuncs.http.MethodType;
import com.aliyuncs.cdn.Endpoint;

/**
 * @author auto create
 * @version 
 */
public class SetL2OssKeyConfigRequest extends RpcAcsRequest<SetL2OssKeyConfigResponse> {
	   

	private String domainName;

	private Long ownerId;

	private String securityToken;

	private String privateOssAuth;
	public SetL2OssKeyConfigRequest() {
		super("Cdn", "2014-11-11", "SetL2OssKeyConfig");
		setMethod(MethodType.POST);
		try {
			com.aliyuncs.AcsRequest.class.getDeclaredField("productEndpointMap").set(this, Endpoint.endpointMap);
			com.aliyuncs.AcsRequest.class.getDeclaredField("productEndpointRegional").set(this, Endpoint.endpointRegionalType);
		} catch (Exception e) {}
	}

	public String getDomainName() {
		return this.domainName;
	}

	public void setDomainName(String domainName) {
		this.domainName = domainName;
		if(domainName != null){
			putQueryParameter("DomainName", domainName);
		}
	}

	public Long getOwnerId() {
		return this.ownerId;
	}

	public void setOwnerId(Long ownerId) {
		this.ownerId = ownerId;
		if(ownerId != null){
			putQueryParameter("OwnerId", ownerId.toString());
		}
	}

	public String getSecurityToken() {
		return this.securityToken;
	}

	public void setSecurityToken(String securityToken) {
		this.securityToken = securityToken;
		if(securityToken != null){
			putQueryParameter("SecurityToken", securityToken);
		}
	}

	public String getPrivateOssAuth() {
		return this.privateOssAuth;
	}

	public void setPrivateOssAuth(String privateOssAuth) {
		this.privateOssAuth = privateOssAuth;
		if(privateOssAuth != null){
			putQueryParameter("PrivateOssAuth", privateOssAuth);
		}
	}

	@Override
	public Class<SetL2OssKeyConfigResponse> getResponseClass() {
		return SetL2OssKeyConfigResponse.class;
	}

}
